@@ -51,6 +51,9 @@
 #include <Rcpp/sugar/functions/tail.h>
 
 #include <Rcpp/sugar/functions/sum.h>
+#include <Rcpp/sugar/functions/mean.h>
+#include <Rcpp/sugar/functions/var.h>
+#include <Rcpp/sugar/functions/sd.h>
 #include <Rcpp/sugar/functions/cumsum.h>
 
 #endif
