@@ -1,7 +1,7 @@
 #!/usr/bin/r -t
 # -*- mode: R; tab-width: 4 -*-
 #
-# Copyright (C) 2010	Dirk Eddelbuettel and Romain Francois
+# Copyright (C) 2010 - 2011  Dirk Eddelbuettel and Romain Francois
 #
 # This file is part of Rcpp.
 #
@@ -18,12 +18,8 @@
 # You should have received a copy of the GNU General Public License
 # along with Rcpp.  If not, see <http://www.gnu.org/licenses/>.
 
-.setUp <- function() {
-	suppressMessages( require( stats ) )
-    tests <- ".rcpp.Function"
-    if( ! exists( tests, globalenv() )) {
-        ## definition of all the functions at once
-        f <- list(
+definitions <- function(){
+    list(
         	"function_" = list(
         		signature(x="ANY"), 'return Function(x) ;'
         	),
@@ -71,14 +67,31 @@
 						) ;
 					return output ;
 				'
+        	),
+        	"function_namespace_env" = list(
+        		signature(),
+        		'
+                Environment ns = Environment::namespace_env( "stats" ) ;
+                Function fun = ns[".asSparse"] ;  // accesses a non-exported function
+                return fun;
+				'
         	)
         )
-  signatures <- lapply(f, "[[", 1L)
-        bodies <- lapply(f, "[[", 2L)
-        fun <- cxxfunction(signatures, bodies,
-                           plugin = "Rcpp", includes = "using namespace std;",
-                           cxxargs = ifelse(Rcpp:::capabilities()[["initializer lists"]],"-std=c++0x",""))
-        getDynLib( fun ) # just forcing loading the dll now
+}
+
+cxxargs <- function(){
+    ifelse(Rcpp:::capabilities()[["initializer lists"]],"-std=c++0x","")
+}
+
+.setUp <- function() {
+	suppressMessages( require( stats ) )
+    tests <- ".rcpp.Function"
+    if( ! exists( tests, globalenv() )) {
+        ## definition of all the functions at once
+        fun <- Rcpp:::compile_unit_tests(
+            definitions(),
+            cxxargs = cxxargs()
+        )
         assign( tests, fun, globalenv() )
     }
 }
@@ -129,3 +142,11 @@ test.Function.binary.call <- function(){
 		msg = "binary_call(Function)" )
 }
 
+test.Function.namespace.env <- function() {
+    funx <- .rcpp.Function$function_namespace_env
+    exportedfunc <- funx()
+    mat <- matrix(1:9, 3)
+    res <- exportedfunc(mat)
+    expected <- stats:::.asSparse(mat)
+	checkEquals( res, expected, msg = "namespace_env(Function)" )
+}
