@@ -2,7 +2,7 @@
 //
 // cache.cpp: Rcpp R/C++ interface class library -- Rcpp cache
 //
-// Copyright (C) 2010	Dirk Eddelbuettel and Romain Francois
+// Copyright (C) 2010 - 2011 Dirk Eddelbuettel and Romain Francois
 //
 // This file is part of Rcpp.
 //
@@ -28,31 +28,31 @@ void maybe_init() {
     if( ! Rcpp_cache_ready ) init_Rcpp_cache() ;
 }
 
-namespace Rcpp{
-    namespace internal{   
-    SEXP get_Rcpp_namespace(){ 
-        maybe_init() ; return VECTOR_ELT( Rcpp_cache , 0 ) ;
-    }
-    SEXP get_rcpptrycatch(){
-       // maybe_init() ; return VECTOR_ELT( Rcpp_cache, 4 ) ; 
-       return Rf_install("rcpp_tryCatch") ;
-    }                              
-    SEXP get_evalq(){
-        // maybe_init() ; return VECTOR_ELT( Rcpp_cache, 5 ) ;
-        return Rf_install("evalq");
-    }
-}
+namespace Rcpp {
+    namespace internal {   
+		SEXP get_Rcpp_namespace(){ 
+			maybe_init() ; return VECTOR_ELT( Rcpp_cache , 0 ) ;
+		}
+		SEXP get_rcpptrycatch(){
+			// maybe_init() ; return VECTOR_ELT( Rcpp_cache, 4 ) ; 
+			return Rf_install("rcpp_tryCatch") ; // maybe not worth assigning to SEXP
+		}                              
+		SEXP get_evalq(){
+			// maybe_init() ; return VECTOR_ELT( Rcpp_cache, 5 ) ;
+			return Rf_install("evalq");	// maybe not worth assigning to SEXP
+		}
+	}
 }
 
 // only used for debugging
 SEXP get_rcpp_cache() { return Rcpp_cache ; }
 
-
 SEXP init_Rcpp_cache(){   
     Rcpp_cache = PROTECT( Rf_allocVector( VECSXP, 10 ) );
-	
+
     // the Rcpp namespace
-    SEXP RCPP = PROTECT( Rf_eval( Rf_lcons( Rf_install("getNamespace"), Rf_cons( Rf_mkString("Rcpp") , R_NilValue) ), R_GlobalEnv ) ) ;
+	SEXP getNamespaceSym = Rf_install("getNamespace"); // cannot be gc()'ed  once in symbol table
+    SEXP RCPP = PROTECT( Rf_eval(Rf_lang2( getNamespaceSym, Rf_mkString("Rcpp") ), R_GlobalEnv) ) ;
     SET_VECTOR_ELT( Rcpp_cache, 0, RCPP ) ;
 	reset_current_error() ;
 	// SET_VECTOR_ELT( Rcpp_cache, 4, Rf_install("rcpp_tryCatch") ) ;
